@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from nova import rpc
 from nova import test
@@ -21,7 +21,7 @@ from nova import test
 
 class TestNotifier(test.NoDBTestCase):
 
-    @mock.patch('oslo_messaging.get_transport')
+    @mock.patch('oslo_messaging.get_rpc_transport')
     @mock.patch('oslo_messaging.get_notification_transport')
     @mock.patch('oslo_messaging.Notifier')
     def test_notification_format_affects_notification_driver(self,
@@ -29,6 +29,8 @@ class TestNotifier(test.NoDBTestCase):
                                                              mock_noti_trans,
                                                              mock_transport):
         conf = mock.Mock()
+        conf.notifications.versioned_notifications_topics = [
+            'versioned_notifications']
 
         cases = {
             'unversioned': [
